/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.sqladmin.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * A database instance resource.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Cloud SQL Administration API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class DatabaseInstance extends GenericJson {

  /**
   * The current disk usage of the instance in bytes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long currentDiskSize;

  /**
   * The database engine type and version, for example MYSQL_5_5 for MySQL 5.5.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String databaseVersion;

  /**
   * Etag for this resource - a version number for the settings object in this resource. This field
   * has no effect when passed as a request parameter. Instead, the contents of this field should be
   * passed in an 'If-Match' http header for use in optimistic locking.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * Name of the database instance. This does not include the project ID.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String instance;

  /**
   * This is always sql#instance.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The maximum disk size of the instance in bytes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long maxDiskSize;

  /**
   * The project ID of the project containing the database instance. The Google apps domain is
   * prefixed if applicable. You can find this on the project summary page of the Google APIs
   * Console.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String project;

  /**
   * The geographical region. Can be us-east1 or europe-west1. Defaults to us-east1. The region can
   * not be changed after instance creation.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String region;

  /**
   * The user settings.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Settings settings;

  /**
   * The current serving state of the database instance. This can be one of the following. RUNNABLE:
   * The instance is running, or is ready to run when accessed. SUSPENDED: The instance is not
   * available, for example due to problems with billing. PENDING_CREATE: The instance is being
   * created. MAINTENANCE: The instance is down for maintenance. UNKNOWN_STATE: The state of the
   * instance is unknown.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String state;

  /**
   * The current disk usage of the instance in bytes.
   * The value returned may be {@code null}.
   */
  public Long getCurrentDiskSize() {
    return currentDiskSize;
  }

  /**
   * The current disk usage of the instance in bytes.
   * The value set may be {@code null}.
   */
  public DatabaseInstance setCurrentDiskSize(Long currentDiskSize) {
    this.currentDiskSize = currentDiskSize;
    return this;
  }

  /**
   * The database engine type and version, for example MYSQL_5_5 for MySQL 5.5.
   * The value returned may be {@code null}.
   */
  public String getDatabaseVersion() {
    return databaseVersion;
  }

  /**
   * The database engine type and version, for example MYSQL_5_5 for MySQL 5.5.
   * The value set may be {@code null}.
   */
  public DatabaseInstance setDatabaseVersion(String databaseVersion) {
    this.databaseVersion = databaseVersion;
    return this;
  }

  /**
   * Etag for this resource - a version number for the settings object in this resource. This field
   * has no effect when passed as a request parameter. Instead, the contents of this field should be
   * passed in an 'If-Match' http header for use in optimistic locking.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * Etag for this resource - a version number for the settings object in this resource. This field
   * has no effect when passed as a request parameter. Instead, the contents of this field should be
   * passed in an 'If-Match' http header for use in optimistic locking.
   * The value set may be {@code null}.
   */
  public DatabaseInstance setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * Name of the database instance. This does not include the project ID.
   * The value returned may be {@code null}.
   */
  public String getInstance() {
    return instance;
  }

  /**
   * Name of the database instance. This does not include the project ID.
   * The value set may be {@code null}.
   */
  public DatabaseInstance setInstance(String instance) {
    this.instance = instance;
    return this;
  }

  /**
   * This is always sql#instance.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * This is always sql#instance.
   * The value set may be {@code null}.
   */
  public DatabaseInstance setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The maximum disk size of the instance in bytes.
   * The value returned may be {@code null}.
   */
  public Long getMaxDiskSize() {
    return maxDiskSize;
  }

  /**
   * The maximum disk size of the instance in bytes.
   * The value set may be {@code null}.
   */
  public DatabaseInstance setMaxDiskSize(Long maxDiskSize) {
    this.maxDiskSize = maxDiskSize;
    return this;
  }

  /**
   * The project ID of the project containing the database instance. The Google apps domain is
   * prefixed if applicable. You can find this on the project summary page of the Google APIs
   * Console.
   * The value returned may be {@code null}.
   */
  public String getProject() {
    return project;
  }

  /**
   * The project ID of the project containing the database instance. The Google apps domain is
   * prefixed if applicable. You can find this on the project summary page of the Google APIs
   * Console.
   * The value set may be {@code null}.
   */
  public DatabaseInstance setProject(String project) {
    this.project = project;
    return this;
  }

  /**
   * The geographical region. Can be us-east1 or europe-west1. Defaults to us-east1. The region can
   * not be changed after instance creation.
   * The value returned may be {@code null}.
   */
  public String getRegion() {
    return region;
  }

  /**
   * The geographical region. Can be us-east1 or europe-west1. Defaults to us-east1. The region can
   * not be changed after instance creation.
   * The value set may be {@code null}.
   */
  public DatabaseInstance setRegion(String region) {
    this.region = region;
    return this;
  }

  /**
   * The user settings.
   * The value returned may be {@code null}.
   */
  public Settings getSettings() {
    return settings;
  }

  /**
   * The user settings.
   * The value set may be {@code null}.
   */
  public DatabaseInstance setSettings(Settings settings) {
    this.settings = settings;
    return this;
  }

  /**
   * The current serving state of the database instance. This can be one of the following. RUNNABLE:
   * The instance is running, or is ready to run when accessed. SUSPENDED: The instance is not
   * available, for example due to problems with billing. PENDING_CREATE: The instance is being
   * created. MAINTENANCE: The instance is down for maintenance. UNKNOWN_STATE: The state of the
   * instance is unknown.
   * The value returned may be {@code null}.
   */
  public String getState() {
    return state;
  }

  /**
   * The current serving state of the database instance. This can be one of the following. RUNNABLE:
   * The instance is running, or is ready to run when accessed. SUSPENDED: The instance is not
   * available, for example due to problems with billing. PENDING_CREATE: The instance is being
   * created. MAINTENANCE: The instance is down for maintenance. UNKNOWN_STATE: The state of the
   * instance is unknown.
   * The value set may be {@code null}.
   */
  public DatabaseInstance setState(String state) {
    this.state = state;
    return this;
  }

}
